%TEST SCRIPT FOR VDM_APPROX
% generate a ULA steering vector (Vandermonde) from an angle of arrival (AOA),
% possibly add noise and estimate the AOA from the noisy vector by recovering 
% the vandermonde structure
clear all
close all
clc
% Parameters of the demo
theta = -55;     % angle of arrival (in  ]-90, 90] degree)
m=6;            % number of antennas
fc=1e9;         % carrier frequency (in Hz)
Lambda=3e8/fc;  % wavelength
d=Lambda/2;    % half-wavelength inter-antenna spacing (in meter)
SNR=20;        % Signal to Noise Ratio in dB (choose SNR=inf for an exact model)

% Generate ULA steering vector
a = steering_ula(theta,m,fc,d);

% scaling factor
alpha = randn+j*randn;
a = alpha*a;

% add noise
n=randn(size(a))+j*randn(size(a));
sigma=(10^(-SNR/20))*(norm(a(:),'fro')/norm(n(:),'fro'));
a=a+sigma*n;

% estimate the AOA
[phi,alpha_est] = vdm_approx(a,2^16);
theta_est = (180/pi)*asin(Lambda*phi/(2*pi*d));

disp('True AOA in degree')
theta
disp('Estimated AOA in degree')
theta_est
disp(' ')
disp('True scaling factor')
alpha
disp('Estimated scaling factor')
alpha_est